/*
 * @Author: zc
 * @Description: 流程管理
 * @version: 
 * @Date: 2022-08-26 14:43:22
 * @LastEditors: Please set LastEditors
 * @LastEditTime: 2022-11-10 13:24:01
 */
import request from '/@/utils/request';
/**
 * @description: 分页查询流程模板
 * @param {object} params
 * @return {*}
 */
 export const workflowList = (params?: object) => {
	return request({
		url: '/api/v1/Workflow/definition',
		method: 'get',
		params: params,
	});
};
/**
 * @description: 新增流程模板草稿
 * @param {object} data
 * @return {*}
 */
 export const workflowAdd = (data: object) => {
	return request({
		url: '/api/v1/Workflow/definition',
		method: 'post',
		data
	});
};
/**
 * @description: 查询流程模板详情
 * @param {any} id
 * @return {*}
 */
export const getWorkFlowDetail = (id: any) => {
	return request({
		url: `/api/v1/Workflow/definition/${id}`,
		method: 'get',
	});
};
/**
 * @description: 更新流程模板草稿
 * @param {object} data
 * @return {*}
 */
export const workflowUpdate = (data: object) => {
	return request({
		url: '/api/v1/Workflow/definition',
		method: 'put',
		data
	});
};
/**
 * @description: 删除草稿
 * @param {string} id
 * @return {*}
 */
 export const workflowDelete = (id: object) => {
	return request({
		url: `/api/v1/Workflow/definition/${id}`,
		method: 'delete'
	});
};
/**
 * @description: 发布（列表操作）
 * @param {string} id
 * @return {*}
 */
 export const publishOnList = (id: string) => {
	return request({
		url: `/api/v1/Workflow/definition/${id}/publish`,
		method: 'post'
	});
};
/**
 * @description: 发布（保存并发布）
 * @param {object} data
 * @return {*}
 */
 export const publish = (data: object) => {
	return request({
		url: '/api/v1/Workflow/definition/publish',
		method: 'post',
		data
	});
};
/**
 * @description: 启用流程模板
 * @param {string} id
 * @return {*}
 */
 export const workflowEnable= (id: string) => {
	return request({
		url: `/api/v1/Workflow/definition/${id}/enable`,
		method: 'post',
	});
};
/**
 * @description: 禁用流程模板
 * @param {string} id
 * @return {*}
 */
 export const workflowDisable = (id: string) => {
	return request({
		url: `/api/v1/Workflow/definition/${id}/disable`,
		method: 'post'
	});
};
/**
 * @description: 基础信息
 * @param {object} params
 * @return {*}
 */
export const baseData = (params?: object) => {
	return request({
		url: '/api/v1/Workflow/base-data',
		method: 'get',
		params: params,
	});
};
/**
 * @description: 根据基础信息查询下拉框数据
 * @param {string} handlerType
 * @return {*}
 */
export const getSelectList = (handlerType?: string) => {
	return request({
		url: `/api/v1/Workflow/handlerclassify/${handlerType}`,
		method: 'get',
	});
};
/**
 * @description: 查询业务流程是否已经启用模板
 * @param {moduleCode} moduleCode
 * @return {*}
 */
export const WorkflowHasdefine = (moduleCode?: string) => {
	return request({
		url: `/api/v1/Workflow/has-define/${moduleCode}`,
		method: 'get',
	});
};
/**
 * @description: 分页查询流程
 * @param {object} params
 * @return {*}
 */
 export const workflowPaged = (params?: object) => {
	return request({
		url: '/api/v1/Workflow',
		method: 'get',
		params: params,
	});
};
/**
 * @description: 查询当前流程下一节点参数
 * @param {object} params
 * @return {*}
 */
 export const workflowNextsteps = (params?: object) => {
	return request({
		url: '/api/v1/Workflow/nextsteps',
		method: 'get',
		params
	});
};
/**
 * @description: 跳转至任意节点
 * @param {object} data
 * @return {*}
 */
 export const workflowJump = (data: object) => {
	return request({
		url: '/api/v1/Workflow/jump',
		method: 'post',
		data
	});
};
/**
 * @description: 获取跳转参数
 * @param {object} params
 * @return {*}
 */
 export const workflowGetJump = (params: object) => {
	return request({
		url: '/api/v1/Workflow/nextsteps',
		method: 'get',
		params
	});
};
/**
 * @description: 终止流程
 * @param {string} workflowId
 * @return {*}
 */
 export const workflowRerminate = (workflowId?: string) => {
	return request({
		url: `/api/v1/Workflow/terminate/${workflowId}`,
		method: 'get',
	});
};
/**
 * @description: 获取撤回参数
 * @param {object} params
 * @return {*}
 */
 export const workflowRecall = (params?: object) => {
	return request({
		url: '/api/v1/Workflow/recall',
		method: 'get',
		params: params,
	});
};