/**
 * 防抖
 *
 * @param func    功能函数(即要防抖的函数)
 * @param delay   延时时间
 * @param thisArg 功能函数内this的对象
 */
export function debounce(func: Function, delay: number, thisArg?: any) {
    let timer: number;
    return function (...args: any[]) {
        if (timer) {
            window.clearTimeout(timer);
        }
        timer = window.setTimeout(function () {
            func.apply(thisArg, args);
        }, delay)
    }
}
/**
 * 节流（原理同上）
 *
 * @param func    功能函数(即要节流的函数)
 * @param delay   延时时间
 * @param thisArg 功能函数内this的对象
 */
export function throttle(func: Function, delay: number, thisArg?: any) {
    let timeStamp: number;
    return function (...args: any[]) {
        const nowTimeStamp = Date.now();
        if ((!timeStamp) || nowTimeStamp - timeStamp >= delay) {
            func.apply(thisArg, args);
            timeStamp = nowTimeStamp;
        }
    }
}
/**
 * vite引入图片
 *
 * @param name   文件路径
 */
export function getImageUrl(name: string) {
    return new URL(`../assets/images/${name}`, import.meta.url).href;
}
/**
 * 手机号脱敏处理
 * @param phoneNumber  手机号码
 * @returns 返回处理后的手机号码
 */
export function desensitizationPhone(phoneNumber: string) {
    if (!phoneNumber) return "";
    return phoneNumber.replace(/^(.{3})(?:\d+)(.{4})$/, "$1****$2")
}
/**
 * 姓名脱敏处理
 * @param name  姓名
 * @returns 返回处理后的姓名
 */
export function desensitizationName(name: string) {
    if (!name) return "";
    const len = name.length;
    return len <= 3 ? "*" + name.substring(1, len) :
        len > 3 && len <= 6 ? "**" + name.substring(2, len) :
            len > 6 ? name.substring(0, 2) + "****" + name.substring(6, len) : "";
}